![CI workflow](https://github.com/weewx/weewx/actions/workflows/ci.yaml/badge.svg)
[![Poetry](https://img.shields.io/endpoint?url=https://python-poetry.org/badge/v0.json)](https://python-poetry.org/)

# [WeeWX](https://www.weewx.com)
*Open source software for your weather station*

## Description

The WeeWX weather system is written in Python and runs on Linux, MacOSX,
Solaris, and *BSD.  It runs exceptionally well on a Raspberry Pi.  It collects
data from many different types of weather stations and sensors, then generates
plots, HTML pages, and monthly and yearly summary reports. It can push plots,
pages, and reports to a web server, as well as upload weather-related data to 
many online weather services.  Thousands of users worldwide!

See the WeeWX website for [examples](https://weewx.com/showcase.html) of
websites generated by WeeWX, and a [map](https://weewx.com/stations.html) of
stations using WeeWX.

* Robust and hard-to-crash
* Designed with the enthusiast in mind
* Simple internal design that is easily extended (Python skills recommended)
* Large ecosystem of 3rd party extensions
* Internationalized language support
* Localized date/time support
* Support for US and metric units
* Support for multiple skins
* Support for sqlite and MySQL
* Extensive almanac information
* Uploads to your website via FTP, FTPS, or rsync
* Uploads to online weather services
* Requires Python 3.6 or greater

Support for many online weather services, including:

* The Weather Underground
* CWOP
* PWSweather
* WOW
* AWEKAS
* Windy
* Open Weathermap
* WeatherBug
* Weather Cloud
* Wetter
* Windfinder

Support for many data publishing and aggregation services, including:

* MQTT
* InfluxDB

Support for over 70 types of hardware including, but not limited to:

* Davis Vantage Pro, Pro2, Vue, Envoy;
* Oregon Scientific WMR100, WMR300, WMR9x8, and other variants;
* Oregon Scientific LW300/LW301/LW302;
* Fine Offset WH10xx, WH20xx, and WH30xx series (including Ambient, Elecsa, Maplin, Tycon, Watson, and others);
* Fine Offset WH23xx, WH4000 (including Tycon TP2700, MiSol WH2310);
* Fine Offset WH2600, HP1000 (including Ambient Observer, Aercus WeatherSleuth, XC0422);
* Fine Offset GW1000, GW1100, GW2000 (including Ecowitt)
* LaCrosse WS-23XX and WS-28XX (including TFA);
* LaCrosse GW1000U bridge;
* Hideki TE923, TE831, TE838, DV928 (including TFA, Cresta, Honeywell, and others);
* PeetBros Ultimeter;
* RainWise CC3000 and MKIII;
* AcuRite 5-in-1 via USB console or bridge;
* AcuRite Atlas;
* Argent Data Systems WS1;
* KlimaLogg Pro;
* New Mountain;
* AirMar 150WX;
* Texas Weather Instruments;
* Dyacon;
* Meteostick;
* Ventus W820;
* Si1000 radio receiver;
* Software Defined Radio (SDR);
* One-wire (including Inspeed, ADS, AAG, Hobby-Boards).

See the [hardware list](https://www.weewx.com/hardware.html) for a complete
list of supported stations, and for pictures to help identify your hardware!
The [hardware comparison](https://www.weewx.com/hwcmp.html) has specifications
for many different types of hardware, including some not yet supported by
WeeWX.

## Install

[https://weewx.com/docs/quickstarts.html](https://weewx.com/docs/quickstarts.html)

## Download

For current and previous releases:

[https://weewx.com/downloads](https://weewx.com/downloads)

For the latest source code:

[https://github.com/weewx/weewx](https://github.com/weewx/weewx)

## Documentation and Support

Guides for installation, upgrading, and customization:

[https://weewx.com/docs/](https://weewx.com/docs/)

The wiki includes user-contributed extensions and suggestions:

[https://github.com/weewx/weewx/wiki](https://github.com/weewx/weewx/wiki)

Community support can be found at:

[https://groups.google.com/group/weewx-user](https://groups.google.com/group/weewx-user)

## Licensing

WeeWX is licensed under the GNU Public License v3.

## Copyright

© 2009-2024 Thomas Keffer, Matthew Wall, and Gary Roderick
